==> m9s_nereid-5.2.11.tar.gz: m9s_nereid-5.2.11/nereid/csrf.py <==
# The COPYRIGHT file at the top level of this repository contains the full
# copyright notices and license terms.
from flask import request
from flask_wtf.csrf import (
    CSRFProtect, validate_csrf, generate_csrf, same_origin
)


__all__ = ['NereidCsrfProtect']


class NereidCsrfProtect(CSRFProtect):

    def init_app(self, app):
        """
        Reimplementation of CsrfProtect.init_app

        By default `init_app` is strictly for Flask and depend on
        `app.view_functions` to `exempt csrf`. But nereid works on
        `request.endpoint`, hence changed the method just to respect
        `request.endpoint` not `app.view_functions`
        """
        app.jinja_env.globals['csrf_token'] = generate_csrf
        app.config.setdefault(
            'WTF_CSRF_HEADERS', ['X-CSRFToken', 'X-CSRF-Token']
        )
        app.config.setdefault('WTF_CSRF_SSL_STRICT', True)
        app.config.setdefault('WTF_CSRF_ENABLED', True)
        app.config.setdefault('WTF_CSRF_METHODS', ['POST', 'PUT', 'PATCH'])

        def _get_csrf_token():
            # find the ``csrf_token`` field in the subitted form
            # if the form had a prefix, the name will be
            # ``{prefix}-csrf_token``
            for key in request.form:
                if key.endswith('csrf_token'):
                    csrf_token = request.form[key]
                    if csrf_token:
                        return csrf_token

            for header_name in app.config['WTF_CSRF_HEADERS']:
                csrf_token = request.headers.get(header_name)
                if csrf_token:
                    return csrf_token
            return None

        # expose csrf_token as a helper in all templates
        @app.context_processor
        def csrf_token():
            return dict(csrf_token=generate_csrf)

        @app.before_request
        def _csrf_protect():
            # many things come from django.middleware.csrf
            if not app.config['WTF_CSRF_ENABLED']:
                return

            if request.method not in app.config['WTF_CSRF_METHODS']:
                return

            if self._exempt_views or self._exempt_blueprints:
                if not request.endpoint:
                    return

                if request.endpoint in self._exempt_views:
                    return
                if request.blueprint in self._exempt_blueprints:
                    return

            # Since 0.14 flask_wtf raises ValidationError instead of returning
            # True/False
            validate_csrf(_get_csrf_token())

            if request.is_secure and app.config['WTF_CSRF_SSL_STRICT']:
                if not request.referrer:
                    reason = 'Referrer checking failed - no Referrer.'
                    return self._error_response(reason)

                good_referrer = 'https://%s/' % request.host
                if not same_origin(request.referrer, good_referrer):
                    reason = 'Referrer checking failed - origin does not match.'
                    return self._error_response(reason)

            request.csrf_valid = True  # mark this request is csrf valid

==> m9s_nereid-7.0.7.tar.gz: m9s_nereid-7.0.7/nereid/csrf.py <==
# The COPYRIGHT file at the top level of this repository contains the full
# copyright notices and license terms.
from flask import request
from flask_wtf.csrf import CSRFProtect, generate_csrf

__all__ = ['NereidCsrfProtect']


class NereidCsrfProtect(CSRFProtect):

    def init_app(self, app):
        """
        Reimplementation of CsrfProtect.init_app

        By default `init_app` is strictly for Flask and depend on
        `app.view_functions` to `exempt csrf`. But nereid works on
        `request.endpoint`, hence changed the method just to respect
        `request.endpoint` not `app.view_functions`
        """
        app.extensions['csrf'] = self
        app.jinja_env.globals['csrf_token'] = generate_csrf
        app.config.setdefault(
            'WTF_CSRF_HEADERS', ['X-CSRFToken', 'X-CSRF-Token']
        )
        app.config.setdefault('WTF_CSRF_SSL_STRICT', True)
        app.config.setdefault('WTF_CSRF_ENABLED', True)
        app.config.setdefault('WTF_CSRF_CHECK_DEFAULT', True)
        app.config['WTF_CSRF_METHODS'] = set(app.config.get(
            'WTF_CSRF_METHODS', ['POST', 'PUT', 'PATCH', 'DELETE']
        ))
        app.config.setdefault('WTF_CSRF_FIELD_NAME', 'csrf_token')
        app.config.setdefault(
            'WTF_CSRF_HEADERS', ['X-CSRFToken', 'X-CSRF-Token']
        )
        app.config.setdefault('WTF_CSRF_TIME_LIMIT', 3600)
        app.config.setdefault('WTF_CSRF_SSL_STRICT', True)

        # expose csrf_token as a helper in all templates
        @app.context_processor
        def csrf_token():
            return dict(csrf_token=generate_csrf)

        @app.before_request
        def csrf_protect():
            if not app.config['WTF_CSRF_ENABLED']:
                return

            if not app.config['WTF_CSRF_CHECK_DEFAULT']:
                return

            if request.method not in app.config['WTF_CSRF_METHODS']:
                return

            if not request.endpoint:
                return

            if request.blueprint in self._exempt_blueprints:
                return

            if request.endpoint in self._exempt_views:
                return

            self.protect()
